import fs from "node:fs";
import { fileURLToPath } from "node:url";
import { version } from "vite";
import { notFoundTemplate, subpathNotUsedTemplate } from "../../template/4xx.js";
import { stripBase } from "./util.js";
const HAS_FILE_EXTENSION_REGEXP = /^.*\.[^\\]+$/;
const IS_VITE_5 = version.startsWith("5.");
function vitePluginAstroPreview(settings) {
  const { base, outDir, trailingSlash } = settings.config;
  return {
    name: "astro:preview",
    apply: "serve",
    configurePreviewServer(server) {
      server.middlewares.use((req, res, next) => {
        if (!req.url.startsWith(base)) {
          res.statusCode = 404;
          res.end(subpathNotUsedTemplate(base, req.url));
          return;
        }
        const strippedPathname = stripBase(req.url, base);
        const pathname = new URL(strippedPathname, "https://a.b").pathname;
        const isRoot = pathname === "/";
        if (!isRoot) {
          const hasTrailingSlash = pathname.endsWith("/");
          if (hasTrailingSlash && trailingSlash == "never") {
            res.statusCode = 404;
            res.end(notFoundTemplate(pathname, 'Not Found (trailingSlash is set to "never")'));
            return;
          }
          if (!hasTrailingSlash && trailingSlash == "always" && !HAS_FILE_EXTENSION_REGEXP.test(pathname)) {
            res.statusCode = 404;
            res.end(notFoundTemplate(pathname, 'Not Found (trailingSlash is set to "always")'));
            return;
          }
        }
        next();
      });
      return () => {
        const fourOhFourMiddleware = (req, res) => {
          const errorPagePath = fileURLToPath(outDir + "/404.html");
          if (fs.existsSync(errorPagePath)) {
            res.statusCode = 404;
            res.setHeader("Content-Type", "text/html;charset=utf-8");
            res.end(fs.readFileSync(errorPagePath));
          } else {
            const pathname = stripBase(req.url, base);
            res.statusCode = 404;
            res.end(notFoundTemplate(pathname, "Not Found"));
          }
        };
        if (IS_VITE_5) {
          for (const middleware of server.middlewares.stack) {
            if (middleware.handle.name === "vite404Middleware") {
              middleware.handle = fourOhFourMiddleware;
            }
          }
        } else {
          server.middlewares.use(fourOhFourMiddleware);
        }
      };
    }
  };
}
export {
  vitePluginAstroPreview
};
